# rensha256

Commandline to rename a file to it's sha256 digest while keeping the file's extension.

## Example

```
find ~/Documents -maxdepth 1 -type f | rensha256
```

### Installing

```
python setup.py install
```

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags).

## Authors

* **Taylor Monacelli** - *Initial work* - [taylormonacelli](https://github.com/taylormonacelli)
